Index: chrome/browser/cocoa/bookmark_bar_controller.mm |
=================================================================== |
--- chrome/browser/cocoa/bookmark_bar_controller.mm (revision 23676) |
+++ chrome/browser/cocoa/bookmark_bar_controller.mm (working copy) |
@@ -399,9 +399,9 @@ |
initWithParentWindow:[[self view] window] |
profile:profile_ |
node:node]; |
- [controller runModal]; |
+ [controller runAsModalSheet]; |
- // runModal will run the window as a sheet. The |
+ // runAsModalSheet will run the window as a sheet. The |
// BookmarkNameFolderController will release itself when the sheet |
// ends. |
} |